===================================================
pycmox - Python wrapper for ``infras/exchange.cpp``
===================================================


Build requirements
==================
1. C++ compiler with C++11 support (gcc 4.8 or later)
2. `pybind11 <https://pypi.org/project/pybind11/>`_

Installation
============

Installing using ``setup.py``
-----------------------------

::

  python3 setup.py install


Installing using ``pip``
------------------------

::

  pip install pycmox

Requiring in ``requirements.txt``
---------------------------------

::

  pycmox

Requiring in ``setup.py``
-------------------------

::

  install_requires = [
        'pycmox',
  ]


License
=======
Copyright (C) 2021-2024 Matwey V. Kornilov <matwey.kornilov@gmail.com>

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.

